darkhistory.physics.c — DarkHistory documentation

- Repository
- DarkHistory documentation
- DarkHistory
- darkhistory
- darkhistory.physics

- index
- modules
- next
- previous

# darkhistory.physics.c

`darkhistory.physics.` `c` = 29979245800.0

  Speed of light in cm s-1.

#### Previous topic

darkhistory.physics.hbar

#### Next topic

darkhistory.physics.kB

### This Page

Show Source

- © Copyright 2019, Hongwan Liu, Gregory Ridgway and Tracy Slatyer.
- Created using Sphinx 1.8.5.